netapp_ontap.models.aggregate_cloud_storage API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.aggregate_cloud_storage`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AggregateCloudStorageSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AggregateCloudStorage object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `attach_eligible GET`

    Specifies whether the aggregate is eligible for a cloud store to be attached.

  `stores GET`

    Configuration information for each cloud storage portion of the aggregate.

  `tiering_fullness_threshold PATCH`

    The percentage of space in the performance tier that must be used before data is tiered out to the cloud store. Only valid for PATCH operations.